# Generated by roxygen2: do not edit by hand

S3method(print,r4pde.oruns_test)
export(AFSD)
export(BPL)
export(CompMuCens)
export(DSI)
export(DSI2)
export(count_subareas)
export(count_subareas_random)
export(fit_gradients)
export(get_nasapower)
export(join_count)
export(oruns_test)
export(oruns_test_boustrophedon)
export(oruns_test_byrowcol)
export(plot_AFSD)
export(theme_r4pde)
export(windowpane)
export(windowpane_tests)
import(tidyr)
importFrom(car,linearHypothesis)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,rename_with)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(igraph,components)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(interval,ictest)
importFrom(lubridate,days)
importFrom(nasapower,get_power)
importFrom(progress,progress_bar)
importFrom(purrr,map_dfr)
importFrom(rlang,as_label)
importFrom(rlang,enquo)
importFrom(stats,aggregate)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,dist)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(tidyr,pivot_longer)
importFrom(utils,install.packages)
