% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functional_pca.R
\name{plot.r4pde_functional_pca}
\alias{plot.r4pde_functional_pca}
\alias{autoplot.r4pde_functional_pca}
\title{Plot functional PCA results}
\usage{
\method{plot}{r4pde_functional_pca}(
  x,
  type = c("scree", "components", "scores", "reconstruction", "mean"),
  components = c(1, 2),
  curve_id = NULL,
  ...
)

autoplot.r4pde_functional_pca(object, ...)
}
\arguments{
\item{x}{An object of class \code{"r4pde_functional_pca"}.}

\item{type}{Type of plot: "scree", "components", "scores", "reconstruction", or "mean".}

\item{components}{Integer vector of length 2 indicating which components to plot for scores and mean perturbation.}

\item{curve_id}{Optional vector of curve IDs to include in reconstruction plot.}

\item{...}{Additional arguments.}

\item{object}{An object of class \code{"r4pde_functional_pca"}.}
}
\description{
Plot functional PCA results
}
