% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-doc.R
\docType{data}
\name{SpatialRandom}
\alias{SpatialRandom}
\title{SpatialRandom dataset}
\format{
A data frame with:
\describe{
\item{x}{x-coordinate}
\item{y}{y-coordinate}
}
}
\source{
Simulated example
}
\usage{
SpatialRandom
}
\description{
Simulated random spatial binary disease pattern.
}
\keyword{datasets}
