% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_curves.R
\name{plot_curves}
\alias{plot_curves}
\alias{plot_curves.functional_distances}
\alias{plot_curves.functional_dsp}
\title{Plot environment-adjusted epidemic curves by cluster}
\usage{
plot_curves(x, ...)

\method{plot_curves}{functional_distances}(
  x,
  label_fun = NULL,
  palette = NULL,
  alpha = 0.9,
  linewidth = 1.1,
  ...
)

\method{plot_curves}{functional_dsp}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"functional_distances"}.}

\item{...}{Additional arguments.}

\item{label_fun}{Optional function to modify treatment labels.}

\item{palette}{Optional named vector of colors for clusters.}

\item{alpha}{Line transparency.}

\item{linewidth}{Line width.}
}
\value{
A \code{ggplot} object.
}
\description{
Plots environment-adjusted mean epidemic curves for each treatment,
colored according to functional cluster membership.

The returned object is a \code{ggplot} and can be further modified
using standard ggplot2 layers.
}
