% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functional_curves.R
\name{plot.functional_curves}
\alias{plot.functional_curves}
\title{Plot functional_curves}
\usage{
\method{plot}{functional_curves}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"functional_curves"}.}

\item{...}{Additional arguments.}
}
\description{
Plot functional_curves
}
